#coding=utf-8

import time
import hashlib
import requests


###### post请求函数 ######
def requests_post(URL,params):
    try:
        #请求方式post
        response = requests.post(URL,params,timeout=15)
        code = response.status_code
        if code == 200:
            return(response.content.decode('utf-8'))
        else:
            return(code)
    except requests.exceptions.ReadTimeout:
        return('连接超时')
    except requests.exceptions.ConnectionError:
        return('未知服务器')

###### get请求函数 ######
def requests_get(URL,params):
    try:
        # 请求方式get
        response = requests.get(URL,params,timeout=15)
        code = response.status_code
        if code == 200:
            return(response.content.decode('utf-8'))
        else:
            return (code)
    except requests.exceptions.ConnectTimeout:
        return ('连接超时')
    except requests.exceptions.ConnectionError:
        return ('未知服务器')

###### 添加设备 ######
def adddev(deviceID,memberCode,apiKey,devName,URL):
    #接口地址
    URL += '/apisc/adddev'
    #时间戳
    reqTime = str(int(time.time()))
    #请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5(( memberCode+reqTime+apiKey+deviceID ).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceID' : deviceID,
        'devName' : devName,
    }
    # 使用post方式请求
    return requests_post(URL,params)

###### 删除设备 ######
def deldev(deviceID,memberCode,apiKey,devName,URL):
    #接口地址
    URL += '/apisc/deldev'
    #时间戳
    reqTime = str(int(time.time()))
    #请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5(( memberCode+reqTime+apiKey+deviceID ).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceID' : deviceID,
    }
    #使用post方式请求
    return requests_post(URL,params)

###### 获取打印机状态 ######
def getStatus(deviceID,memberCode,apiKey,URL):
    #请求地址
    URL += '/apisc/getStatus'
    #时间戳
    reqTime = str(int(time.time()))
    # 请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5(( memberCode+reqTime+apiKey ).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceID' : deviceID,
    }
    # 使用post方式请求
    return requests_post(URL, params)

###### 发送打印订单 ######
def sendMsg(deviceNo,msgDetail,memberCode,apiKey,msgNo,mode,URL,charset):
    #时间戳
    reqTime = str(int(time.time()))
    #请求地址
    URL += "/apisc/sendMsg"
    if msgNo != None:
        #无订单号请求参数
         params = {
             'reqTime' : reqTime,
             'securityCode' : hashlib.md5((memberCode+deviceNo+msgNo+reqTime+apiKey).encode('utf-8')).hexdigest(),
             'memberCode' : memberCode,
             'deviceNo' : deviceNo,
             'mode' : mode,
             'charset': charset,
             'msgDetail': msgDetail,
             'msgNo': msgNo,
             'reprint': 0,
             'times' : 1,
             'voice' : None,
             'multi' : 0,
         }
    else:
        #有订单号请求参数
        params = {
            'reqTime': reqTime,
            'securityCode': hashlib.md5((memberCode + deviceNo + reqTime + apiKey).encode('utf-8')).hexdigest(),
            'memberCode': memberCode,
            'deviceNo': deviceNo,
            'mode': mode,
            'charset': charset,
            'msgDetail': msgDetail,
            'reprint': 0,
            'times': 1,
            'voice': None,
            'multi': 0,
        }
    # 使用post方式请求
    return requests_post(URL,params)

###### 查询订单状态 #####
def queryState(msgNo,memberCode,apiKey,URL):
    # 时间戳
    reqTime = str(int(time.time()))
    # 请求地址
    URL += '/apisc/queryState'
    # 请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5((memberCode+reqTime+apiKey+msgNo).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'msgNo' : msgNo,
    }
    # 使用get方式请求
    return requests_get(URL,params)

###### 清除打印任务 ######
def cancelPrint(deviceID,memberCode,apiKey,URL):
    # 时间戳
    reqTime = str(int(time.time()))
    # 请求地址
    URL += "/apisc/cancelPrint"
    # 请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5((memberCode+reqTime+apiKey+deviceID).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceID' : deviceID,
        'all' : 1,
    }
    # 使用post方式请求
    return requests_post(URL,params)

###### 发送语音 ######
def sendVoice(deviceNo,memberCode,apiKey,voice,URL):
    # 时间戳
    reqTime = str(int(time.time()))
    # 入口URL
    URL += '/apisc/sendVoice'
    # 请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5((memberCode+deviceNo+reqTime+apiKey).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceNo' : deviceNo,
        'voice' : voice,
    }
    # 使用post方式请求
    return requests_post(URL,params)

###### 设置打印机音量 ######
def sendVolume(deviceID,memberCode,apiKey,volume,URL):
    # 时间戳
    reqTime = str(int(time.time()))
    # 入口URL
    URL += '/apisc/sendVolume'
    # 请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5((memberCode+deviceID+reqTime+apiKey).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceID' : deviceID,
        'volume' : volume,
    }
    # 使用post方式请求
    return requests_post(URL,params)

###### 固件升级 ######
def romupdate(deviceID,memberCode,apiKey,version,URL):
    #接口地址
    URL += '/apisc/romupdate'
    #时间戳
    reqTime = str(int(time.time()))
    #请求参数
    params = {
        'reqTime' : reqTime,
        'securityCode' : hashlib.md5(( memberCode+reqTime+apiKey+deviceID ).encode('utf-8')).hexdigest(),
        'memberCode' : memberCode,
        'deviceID' : deviceID,
        'version' : version,
    }
    # 使用post方式请求
    return requests_post(URL,params)





